import logging
import socket

from zeroconf import IPVersion
from zeroconf.asyncio import AsyncServiceInfo, AsyncZeroconf

LOGGER = logging.getLogger(__name__)

# From https://stackoverflow.com/questions/166506/finding-local-ip-addresses-using-pythons-stdlib/
def get_ip() -> str:
	"Get the primary IP"
	LOGGER.info("Determining IP address")
	s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
	s.settimeout(0)
	try:
		# doesn't even have to be reachable
		s.connect(('10.254.254.254', 1))
		ip = s.getsockname()[0]
	except Exception:
		ip = '127.0.0.1'
	finally:
		s.close()
	LOGGER.info("IP address seems to be %s", ip)
	return ip

async def handle(*args):
	"Handle requests for discovery"
	ip = get_ip()
	info = AsyncServiceInfo(
		"_http._tcp.local.",
		"pnpdevice._http._tcp.local.",
		addresses=[socket.inet_aton("127.0.0.1")],
		port=80,
		server=ip,
	)
	aiozc = AsyncZeroconf(ip_version=IPVersion.V4Only)
	await aiozc.async_register_service(info)
